@@ -148,11 +148,13 @@ class CatBoostMetrics(pl.callbacks.Callback):
         *args,
         plot_dependence=False,
         max_dataset_size_for_complex_shap=1000,
+        figsize=(8, 5),
         **kwargs,
     ):
         super().__init__(*args, **kwargs)
         self.plot_dependence = plot_dependence
         self.max_dataset_size_for_complex_shap = max_dataset_size_for_complex_shap
+        self.figsize = figsize
 
     def on_train_end(self, trainer, pl_module: "LitRecommenderBase"):
         self.log_feature_names(model=pl_module.model)
@@ -196,10 +198,12 @@ class CatBoostMetrics(pl.callbacks.Callback):
 
         shap_kwargs = model.shap_kwargs(user_item_dataframe=user_item_dataframe)
 
-        self.log_shap_summary_plot(**shap_kwargs, stage=stage)
+        self.log_shap_summary_plot(**shap_kwargs, stage=stage, figsize=self.figsize)
 
         if self.plot_dependence:
-            self.log_shap_dependence_plots(**shap_kwargs, stage=stage)
+            self.log_shap_dependence_plots(
+                **shap_kwargs, stage=stage, figsize=self.figsize
+            )
 
         if len(user_item_dataframe) > self.max_dataset_size_for_complex_shap:
             user_item_dataframe = user_item_dataframe.sample(
@@ -213,7 +217,9 @@ class CatBoostMetrics(pl.callbacks.Callback):
         pool_kwargs = model.extract_pool_kwargs(dataframe=dataframe)
         postprocessed_pool_kwargs = model.postprocess_pool_kwargs(**pool_kwargs)
         shap_explanation = model.shap_explainer(X=postprocessed_pool_kwargs["data"])
-        self.log_shap_heatmap_plot(shap_explanation=shap_explanation, stage=stage)
+        self.log_shap_heatmap_plot(
+            shap_explanation=shap_explanation, stage=stage, figsize=self.figsize
+        )
 
     @staticmethod
     def log_feature_names(model: "CatboostInterface"):
@@ -302,11 +308,15 @@ class CatBoostMetrics(pl.callbacks.Callback):
 
     @staticmethod
     def log_shap_dependence_plots(
-        base_value: float, shap_values: np.array, features: pd.DataFrame, stage: str
+        base_value: float,
+        shap_values: np.array,
+        features: pd.DataFrame,
+        stage: str,
+        figsize,
     ):
         for feature_name in list(features):
             with wandb_plt_figure(
-                title=f"shap/dependence plot/{stage} " + feature_name
+                title=f"shap/dependence plot/{stage} " + feature_name, figsize=figsize
             ) as figure:
                 shap.dependence_plot(
                     feature_name,
@@ -317,14 +327,18 @@ class CatBoostMetrics(pl.callbacks.Callback):
 
     @staticmethod
     def log_shap_summary_plot(
-        base_value: float, shap_values: np.array, features: pd.DataFrame, stage: str
+        base_value: float,
+        shap_values: np.array,
+        features: pd.DataFrame,
+        stage: str,
+        figsize,
     ):
-        with wandb_plt_figure(title=f"shap/{stage} summary plot"):
+        with wandb_plt_figure(title=f"shap/{stage} summary plot", figsize=figsize):
             shap.summary_plot(shap_values=shap_values, features=features)
 
     @staticmethod
-    def log_shap_heatmap_plot(shap_explanation: shap.Explanation, stage: str):
-        with wandb_plt_figure(title=f"shap/{stage} heatmap plot"):
+    def log_shap_heatmap_plot(shap_explanation: shap.Explanation, stage: str, figsize):
+        with wandb_plt_figure(title=f"shap/{stage} heatmap plot", figsize=figsize):
             shap.plots.heatmap(shap_values=shap_explanation)
 
 
